@@ -5,7 +5,7 @@
 # SPDX-FileCopyrightText: 2024 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from typing import Dict, Optional, TypeVar
+from typing import TypeVar
 
 from univention.management.console.modules.setup.netconf.conditions import AddressChange, SkipPhase
 
@@ -19,12 +19,12 @@ class PhaseSaveOldApplianceAddress(AddressChange):
     priority = 1
 
     def check(self) -> None:
-        super(PhaseSaveOldApplianceAddress, self).check()
+        super().check()
         if not self.changeset.options.appliance_mode:
             raise SkipPhase("Save only in appliance-mode")
 
     def pre(self) -> None:
-        super(PhaseSaveOldApplianceAddress, self).pre()
+        super().pre()
         new_ipv4s = {iface.ip for iface in self.changeset.new_ipv4s}
         for name, iface in self.changeset.old_interfaces.ipv4_interfaces:
             if ':' in name:
@@ -33,7 +33,7 @@ class PhaseSaveOldApplianceAddress(AddressChange):
             if ipv4 not in new_ipv4s:
                 self.rewrite(name, iface)
 
-    def rewrite(self, name: str, iface: Dict[str, str]) -> None:
+    def rewrite(self, name: str, iface: dict[str, str]) -> None:
         self.logger.info("Rewriting %s=%r...", name, iface)
         tmp_iface = self._copy_iface(iface)
         new_name = self.find_next_interface(name)
@@ -42,8 +42,8 @@ class PhaseSaveOldApplianceAddress(AddressChange):
         self.changeset.update_config(new_iface)
 
     @staticmethod
-    def _copy_iface(iface: Dict[str, str]) -> Dict[str, Optional[str]]:
-        tmp_iface: Dict[str, Optional[str]] = {
+    def _copy_iface(iface: dict[str, str]) -> dict[str, str | None]:
+        tmp_iface: dict[str, str | None] = {
             "type": "appliance-mode-temporary",
         }
         for key in ("address", "network", "netmask", "broadcast"):
@@ -51,7 +51,7 @@ class PhaseSaveOldApplianceAddress(AddressChange):
         return tmp_iface
 
     @staticmethod
-    def _prefix_iface(prefix: str, iface: Dict[str, _V]) -> Dict[str, _V]:
+    def _prefix_iface(prefix: str, iface: dict[str, _V]) -> dict[str, _V]:
         new_iface = {
             "interfaces/%s/%s" % (prefix, key): value
             for key, value in iface.items()
